# bmondata
Allows easy access to sensor data residing on a [BMON Server](https://github.com/alanmitchell/bmon).

This package provides a wrapper around the the BMON API, version 2.  It allows retrieval
of key data stored in the BMON database, including sensor readings, sensor metadata, building
information, and organization information.  It is not comprehensive as some BMON information is
not available.  It also allows for storage of new sensor readings in a BMON
sensor reading database.
